<?php
/**
* Template Name: Authors
*/

get_header(); 


/**
 * Check enabled CoAuthors.
 */
function powerkit_coauthors_enabled() {
	return class_exists( 'CoAuthors_Plus' );
}

/**
 * Retrieve list of guests.
 */
function powerkit_get_guests() {

	$list = wp_cache_get( 'powerkit_get_guests' );

	if ( ! $list ) {

		$list = array();

		$query = new WP_Query();

		$guests = $query->query( array(
			'post_type'      => 'guest-author',
			'post_status'    => 'publish',
			'posts_per_page' => -1,
		) );

		foreach ( $guests as $guest ) {
			array_push( $list, $guest );
		}

		wp_cache_set( 'powerkit_get_guests', $list, 'powerkit', 1 );
	}

	return $list;
}

/**
 * Determines whether a user is a guest.
 *
 * @param int $id The id of guest.
 */
function powerkit_is_guest( $id ) {
	if ( ! powerkit_coauthors_enabled() ) {
		return false;
	}

	if ( ! is_numeric( $id ) ) {
		return false;
	}

	$guests = powerkit_get_guests();

	foreach ( $guests as $guest ) {
		if ( (int) $id === (int) $guest->ID ) {
			return true;
		}
	}
}

/**
 * Retrieve guest info by a given field.
 *
 * @param string $field The field of guest.
 * @param int    $id    The id of guest.
 */
function powerkit_get_guest_meta( $field, $id ) {
	$field = str_replace( array( 'user_url', 'url' ), 'website', $field );

	return get_post_meta( $id, 'cap-' . $field, true );
}

/**
 * Retrieve list of users and guests.
 */
function powerkit_get_users() {

	$users = wp_cache_get( 'powerkit_get_users' );

	if ( ! $users ) {
		$users = get_users( array(
			'orderby' => 'display_name',
		) );

		if ( powerkit_coauthors_enabled() ) {

			$guests = powerkit_get_guests();

			foreach ( $guests as $guest ) {
				$guest->first_name = powerkit_get_guest_meta( 'first_name', $guest->ID );
				$guest->last_name  = powerkit_get_guest_meta( 'last_name', $guest->ID );
				$guest->user_email = powerkit_get_guest_meta( 'user_email', $guest->ID );
				$guest->website    = powerkit_get_guest_meta( 'website', $guest->ID );

				$user = (object) array(
					'ID'                  => $guest->ID,
					'display_name'        => $guest->post_title,
					'user_registered'     => $guest->post_date,
					'user_login'          => $guest->first_name,
					'user_nicename'       => $guest->last_name,
					'user_email'          => $guest->user_email,
					'user_url'            => $guest->website,
					'user_pass'           => '',
					'user_activation_key' => '',
					'user_status'         => 0,
				);

				array_push( $users, $user );
			}
		}

		wp_cache_set( 'powerkit_get_users', $users, 'powerkit', 1 );
	}

	usort( $users, function( $a, $b ) {
		if ( function_exists( 'mb_strtolower' ) ) {
			return strcmp( mb_strtolower( $a->display_name ), mb_strtolower( $b->display_name ) );
		} else {
			return strcmp( strtolower( $a->display_name ), strtolower( $b->display_name ) );
		}
	} );

	return $users;
}

/**
 * Check the user's belonging to the post.
 *
 * @param int $author_id The ID of author.
 * @param int $post_id   The ID of post.
 */
function powerkit_check_post_author( $author_id, $post_id ) {

	if ( (string) get_post_field( 'post_author', $post_id ) === (string) $author_id ) {
		return true;
	}

	if ( powerkit_coauthors_enabled() ) {
		$coauthors = (array) get_coauthors();

		foreach ( $coauthors as $coauthor ) {
			if ( isset( $coauthor->ID ) && (string) $coauthor->ID === (string) $author_id ) {
				return true;
			}
		}
	}
}

?>

<div class="content-holder clearfix">
    <div class="container">         
<?php get_template_part('title'); ?>
                <div class="row">
                    <div class="col-md-12" id="content">
			
                        <?php 
						
						
	$authors = powerkit_get_users();


if ( isset( $authors ) && ! empty( $authors ) ) {
	?>
	<div class="cs-meet-team">
		<?php
		foreach ( $authors as $author ) {

			$args = array(
				'posts_per_page'   => 6,
				'suppress_filters' => true,
			);

			if ( powerkit_is_guest( $author->ID ) ) {

				$terms = wp_get_object_terms( $author->ID, 'author', array(
					'fields' => 'ids',
				) );

				$args['tax_query'] = array(
					array(
						'taxonomy' => 'author',
						'field'    => 'id',
						'terms'    => $terms,
					),
				);

			} else {
				$args['author'] = $author->ID;
			}

			$query = new WP_Query( apply_filters( 'csco_meet_team_args', $args ) );

			if ( $query->have_posts() ) {
			?>
				<div class="cs-author">
					<div class="cs-author-info">
						<div class="cs-author-meta">
							<div class="cs-author-avatar">
								<a href="<?php echo esc_url( get_author_posts_url( $author->ID ) ); ?>" rel="author">
									<?php echo get_avatar( $author->ID, 60 ); ?>
								</a>
							</div>

							<h3 class="cs-author-title">
									<a href="<?php echo esc_url( get_author_posts_url( $author->ID ) ); ?>" rel="author">
										<?php echo esc_html( get_the_author_meta( 'display_name', $author->ID ) ); ?>
									</a>
							</h3>

							<div class="author-social">
		<?php if(get_the_author_meta('url')) : ?><a target="_blank" class="author-social" href="<?php echo esc_url(the_author_meta('url')); ?>"><i class="hs-icon fa fa-globe"></i></a><?php endif; ?>
		<?php if(get_the_author_meta('facebook')) : ?><a target="_blank" class="author-social" href="<?php echo esc_url(the_author_meta('facebook')); ?>"><i class="hs-icon hs hs-facebook"></i></a><?php endif; ?>
		<?php if(get_the_author_meta('twitter')) : ?><a target="_blank" class="author-social" href="<?php echo esc_url(the_author_meta('twitter')); ?>"><i class="hs-icon hs hs-twitter"></i></a><?php endif; ?>
		<?php if(get_the_author_meta('instagram')) : ?><a target="_blank" class="author-social" href="<?php echo esc_url(the_author_meta('instagram')); ?>"><i class="hs-icon hs hs-instagram"></i></a><?php endif; ?>
		<?php if(get_the_author_meta('google')) : ?><a target="_blank" class="author-social" href="<?php echo esc_url(the_author_meta('google')); ?>"><i class="hs-icon hs hs-gplus"></i></a><?php endif; ?>
		<?php if(get_the_author_meta('pinterest')) : ?><a target="_blank" class="author-social" href="<?php echo esc_url(the_author_meta('pinterest')); ?>"><i class="hs-icon hs hs-pinterest"></i></a><?php endif; ?>
		<?php if(get_the_author_meta('tumblr')) : ?><a target="_blank" class="author-social" href="<?php echo esc_url(the_author_meta('tumblr')); ?>"><i class="hs-icon hs hs-tumblr"></i></a><?php endif; ?>
		<?php if(get_the_author_meta('snapchat')) : ?><a target="_blank" class="author-social" href="<?php echo esc_url(the_author_meta('snapchat')); ?>"><i class="hs-icon hs hs-snapchat"></i></a><?php endif; ?>
		</div>
						</div>
						<div class="cs-author-description">
							<?php echo wp_kses_post( get_the_author_meta( 'description', $author->ID ) ); ?>
						</div>
					</div>

					<div class="cs-author-posts">
						<?php $tag = apply_filters( 'csco_section_title_tag', 'h5' ); ?>
						<<?php echo esc_html( $tag ); ?> class="author-title-posts title-block">
							<?php esc_html_e( 'Latest from ', 'authentic' ); ?> <?php echo esc_html( get_the_author_meta( 'display_name', $author->ID ) ); ?>
						</<?php echo esc_html( $tag ); ?>>

						<ul class="author-list-posts cs-list-articles">
							<?php
							while ( $query->have_posts() ) {
								$query->the_post();
								?>
								<li>
									<a href="<?php the_permalink(); ?>">
										<?php the_title(); ?>
									</a>
								</li>
								<?php
							}
							?>
						</ul>
					</div>
				</div>
			<?php
			}
			wp_reset_postdata();
		}
		?>
	</div>
	<?php
}
						
						?>
						
                    </div>
                </div>
    </div>
</div>

<?php get_footer(); ?>